createviewport : Wrapup for createviewport in package grid
Description
create regions in where to print graphs. Used for the generation of printouts
Usage
createviewport( name, left, top, width, height, pwidth = 8.27,
pheight = 11.69 )Arguments
left
a numeric vector or unit object specifying left location (in inches)
top
a numeric vector or unit object specifying topvflocation (in inches)
width
a numeric vector or unit object specifying width (in inches)
height
a numeric vector or unit object specifying height (in inches)
pwidth
width of the page (in inches). Default is 8.27
pheight
height of the page (in inches). Default is 11.69
Value
returns a viewport object
Details
create regions in where to print graphs. Used for the generation of printouts
Examples
Run this code# NOT RUN {
# show a printout
#vflayout( vf91016right[15,] )
# }
Run the code above in your browser using DataLab