Learn R Programming

visualFields (version 0.2-4)

filterReliability: identify visual fields that did not pass filter for reliability

Description

identify visual fields that did not pass filter for reliability

Usage

filterReliability( vf, relCriteria = c( 0.2, 0.2, 0.2 ) )

Arguments

vf
visual field, should have columns perc of false positives, false negatives, and fixation losses
relCriteria
reliability limits for false positives, false negatives, and fixation losses

Value

  • returns a list of visual fields that did not pass the reliability criteria

See Also

lidLensArtifact

Examples

Run this code
# DO NOT RUN
#idx <- filterReliability( vf )

Run the code above in your browser using DataLab