Learn R Programming

visualFields (version 0.2-4)

ghpostd: general height estimated as the rankRef-th ranked TD location

Description

gets the general height estimated as the rankRef-th ranked TD location

Usage

ghpostd( td, correction = FALSE, rankRef = c( "default" ) )

Arguments

td
vf-object with total-deviation values
correction
obtain general height as difference from mean normal "85th" percentile TD value? Default is FALSE
rankRef
the rank position to take as reference for general height. Default is "default". For "default" it looks at the type of visual field, p24d2 or p30d2, fullt or sitas, to get which is the position that corr

Value

  • returns the subject's estimated general height

Details

calculates the general height estimated as the pos-th ranked TD location

See Also

pdval

Examples

Run this code
td <- tdval( vf91016right[15,] )
ghseventh <- ghpostd( td )

Run the code above in your browser using DataLab