Learn R Programming

visualFields (version 0.2-4)

gloperc: percentiles for global indices

Description

gets the percentiles for global indices

Usage

gloperc( vals, percentiles = c( 0.5, 1, 2, 5, 95 ),
         type = c( "quantile", "(i-1)/(n-1)", "i/(n+1)", "i/n" ) )

Arguments

vals
table with global indices for control subjects
percentiles
percentiles at which to calculate cutoff values
type
see wtd.quantile for a list of different options

Value

  • percentiles for global indices

Details

gets the percentiles for global indices. This function works in conjunction with vfstats. In vfstats all global indices refering to mean must start with m and all refereing to standard deviation must start with s, otherwise gloperc won't calculate the cutoff values correctly

See Also

vfindex, vfstats, vfiperc, locperc

Examples

Run this code
# DO NOT RUN
# gperc <- gloper()

Run the code above in your browser using DataLab