Learn R Programming

visualFields (version 0.2-4)

lidLensArtifact: visual fields with lid or lens artifacts

Description

identifies in a very coarse way visual fields that may have been affected by lid or lens artifacts. This function is to be used only with control data. It is probably better not to use it and look to the visual-fields printouts directly to identify those with lid and lens artifacts

Usage

lidLensArtifact( vf, min_dB = c( 12 ) )

Arguments

vf
visual-field object
min_dB
lowest dB value considered normal

Value

  • it returns a list of indices of visual fields in vf that may have been affected by lid or lens artifact

See Also

filterReliability

Examples

Run this code
# DO NOT EXECUTE
#idx <- lidLensArtifact( vf )

Run the code above in your browser using DataLab