Learn R Programming

visualFields (version 0.2-4)

loadvfcsv: load visual fields from a CSV file

Description

loads visual fields from a CSV file

Usage

loadvfcsv( filename, patternMap )

Arguments

filename
filename
patternMap
pattern of stimulus locations

Value

  • returns a vf-object with all the data in the CSV file filename

Details

The columns in the CSV file must follow the format of vf. Make sure that all dates have the format MM/DD/YYYY and all times have the format HH:MM:SS. Excel tends to change the format, and any edits in Excel that are safe may cause problems when loading the data as vf-object

See Also

loadvfxml, loadvfxmlbatch

Examples

Run this code
# DO NOT RUN
#filename <- # Add the file name with the control data
#vf       <- loadvfxml( filename = filename, patternMap = saplocmap$p24d2 )

Run the code above in your browser using DataLab