filename in CSV format with the list of XML files to upload and whether the subject whose data is in the XML file is a patient with glaucoma pwg or a control ctr
patternMap
pattern of stimulus locations. Default is saplocmap$p24d2
typeData
Type of data to load; visual field (vf), total deviations (td), pattern deviations (pd), global indices (gi), visual-field index (vfi), total-deviation p-values (tdp), pattern-d
Value
returns a vf-object with as many rows as XML files exists in filename