Learn R Programming

visualFields (version 0.2-8)

nv: version of normative values used at present in visualFields

Description

variable containing the current version of normative values to be used with visualFields. The default used is sapsunyiunv

Usage

data( nv )

Arguments

See Also

getnv,setnv