p-values. Typically the ones obtained from poplr_pstat
typecomb
Combination type for p-values. Default is fisher, by now the only one implemented
truncation
p-value cut-off for truncation. Default is 1
minmax
whether to use minimum p-value if empty combination statistic after truncation. Default is TRUE
spatialwtd
Weights for spatial autocorrelation. Typically the p-values, the slope, or the Spearman rank correlation obtained with poplr_pstat. If NULL, then the weights are all 1
distance
Pairwise distances between locations. Default is NULL
eccwtd
Eccentricity-related weights. Ask Neil. Default is NULL