Learn R Programming

visualFields (version 0.2-4)

progols: progression by linear ordinary least squares

Description

makes a linear regression with projection in the future by projyears years

Usage

progols( tdate, index, projyears = 5,
         xlab = "years from first visit", ylab = "md",
         txtfont = "mono", pointsize = 12, cex = 1 )

Arguments

tdate
visit date
index
index measured at the corresponding age
xlab
label for x-axis. Default is age
ylab
label for y-axis. Default is md
projyears
Years for projection. Default is 5
txtfont
font of the text with visual-sensitivity values. Default is mono
pointsize
size of the text with visual-sensitivity values. Default is 12
cex
a numerical value giving the amount by which plotting text and symbols should be magnified relative to the default. Default is 1

Examples

Run this code
vfi <- vfindex( vf91016right )
progols( vfi$tdate, vfi$mvfi, ylab = "vfi" )

Run the code above in your browser using DataLab