Learn R Programming

visualFields (version 0.2-4)

quad2Dfit: two-dimensional quadratic fitting for visual-field results

Description

fits a 2D quadratic function using values in val as "observations" for the x and y coordinates in patternMap

Usage

quad2Dfit( val, patternMap = saplocmap$p24d2,
           bspos = vfsettings$p24d2$bs )

Arguments

val
values at each location
patternMap
pattern of stimulus locations. It uses the x and y coordinates in conjunction with val to get the fitted values with the 2D model
bspos
position of the blind spot

Value

  • fitted values by a 2D quadratic function

See Also

ageLinearModel

Examples

Run this code
# DO NOT RUN
# to test this, load a file using e.g. loadvfcsv with control data and then run
# agelm <- ageLinearModel( vf )

Run the code above in your browser using DataLab