Learn R Programming

visualFields (version 0.2-4)

ringmapgraph: ring legend for p-values

Description

It geneartes ring legend for p-values

Usage

ringmapgraph( ncol = 3, mapval = NULL, txtfont = "mono", pointsize = 7,
               outerSymbol = "circles", innerSymbol = "circles",
               outerSize = 1, innerSize = 1,
               outerInch = 0.2, innerInch = 0.1,
               outerBorderThickness = 2, innerBorderThickness = 2 )

Arguments

ncol
number of columns in where to show the color symbols. Default is 3
mapval
map and cutoff values to be used for the generation of the color map. Default is NULL
txtfont
font of the text with visual-sensitivity values. Default is mono
pointsize
size of the text with visual-sensitivity values. Default is 7
outerSymbol
The outer symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
innerSymbol
The inner symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
outerSize
Size of the outer symbol. Default is 1
innerSize
Size of the inner symbol. Default is 1
outerInch
Maximum size of the outer symbol in inches. Default is 0.2
innerInch
Maximum size of the inner symbol in inches. Default is 0.1
outerBorderThickness
Thickness of outer border for outer symbol denoting statistical significance. Default is 2
innerBorderThickness
Thickness of the inner border that represents statistical significance. Default is 2

See Also

vfcolormap

Examples

Run this code
ringmapgraph()

Run the code above in your browser using DataLab