whether to use a function to smooth the results or not. Default is TRUE
smoothFunction
If smooth is true, the function to use for smoothing. Default is quad2Dfit, a 2D quadratic fit to resulting data. This function is not really a smoothing procedure, but a parametric fit
Value
returns a 3-column data frame with SDs per location. Each row is a location. Column 1 is for sensitivities, column 2 for total deviation, and column 3 for pattern deiation.
Details
calculates total-deviation and pattern-deviation values and, from them, their standard deviation at each location