gets percentiles for TD rank curve
tdranknv( td, smooth = TRUE, smoothFunction = tdrankglm )table with total-deviation values
whether to use a function to smooth the results or not. Default is TRUE
if smooth is TRUE, the function to use for smoothing. Default is tdrankglm, a GLM fit which was proven to do a good fit for average over subject of TD rank curves. This function is not really a smoothing procedure, but a parametric fit
percentiles for TD rank curves
details