Learn R Programming

visualFields (version 0.2-4)

vfindex: visual field index

Description

calculates the visual field index. It can be parametrized by re-defining which locations go to which weighting regions and the actual weights per region.

Usage

vfindex( vf, td2pdcutoff = -20, perc = 5, vfiset = vfidefault )

Arguments

vf
stimulus sensitivities in dBs
td2pdcutoff
cutof value for mean deviation. See perc below for an explanation of how both criteria work in conjunction. Default is -20
perc
percentile at which to check whether the 85th TD percentile is within normal limits or not. If it is not and mean deviation is lower than td2pdcutoff, then TD probability maps are to be used instead of PD probability maps. Default is 5th perc
vfiset
settings to be applied for the calculation of VFI

Details

calculates the visual field index. It can be parametrized by re-defining which locations go to which weighting regions and the actual weights per region.

References

[1] B. Bengtsson and A. Heijl. A visual field index for calculation of glaucoma rate of progression. American Journal of Ophthalmology, 145, 2008

See Also

vfstats, vfstatspmap, vfindexpmap

Examples

Run this code
vfi <- vfindex( vf91016right )

Run the code above in your browser using DataLab