Learn R Programming

visualFields (version 0.2-4)

vflayout: printout with results for the visual field

Description

creates a printout with results for the visual field. This includes sensitivity threshold values with a gray scale plot, and TD and PD values with color coding for the probability map

Usage

vflayout( vf, pwidth = 8.27, pheight = 11.69, margin = 0.25,
          filename = NULL )

Arguments

vf
vf-object with sensitivity thresholds
pwidth
width of the page (in inches). Default is 8.27
pheight
height of the page (in inches). Default is 11.69
margin
margins of the page (in inches). Default is 0.25
filename
file name to save the printout as pdf. If it is saved to pdf, it won't be displayed in the screen. Default is NULL.

See Also

vflayout_poplr, vflayout_legoplot

Examples

Run this code
# show a printout
vflayout( vf91016right[15,] )

Run the code above in your browser using DataLab