Learn R Programming

visualFields (version 0.2-4)

vflayout_legoplot: legoplot visualization for change in sensitivities over time of visual fields

Description

displays a legoplot visualization for change in sensitivities over time of visual fields

Usage

vflayout_legoplot( vf, grp = 3, pwidth = 8.27, pheight = 11.69,
                   margin = 0.25, filename = NULL )

Arguments

vf
vf-object with sensitivity thresholds
grp
how many visual fields to group. Default is 3
pwidth
width of the page (in inches). Default is 8.27
pheight
height of the page (in inches). Default is 11.69
margin
margins of the page (in inches). Default is 0.25
filename
file name to save the printout as pdf. If it is saved to pdf, it won't be displayed in the screen. Default is NULL.

See Also

vflayout, vflayout_poplr

Examples

Run this code
vflayout_legoplot( vf91016right )

Run the code above in your browser using DataLab