Learn R Programming

visualFields (version 0.2-4)

vflayout_poplr: layout displaying the PoPLR analysis

Description

the function performs the PoPLR analysis (see poplr) with default values and presents the results in form of a A4 printout

Usage

vflayout_poplr( vf, grp = 3, nperm = 5000, pwidth = 8.27, pheight = 11.69,
                margin = 0.25, filename = NULL,
                colorMapType = "pval", colorScale = NULL,
                ringMapType  = NULL,  ringScale  = NULL,
                lifeExpectancy = 81.27, imparedVision = 10,
                rangeNormal = NULL )

Arguments

vf
vf object with threshold sensitivities, td, or pd values
grp
how many visual fields to group. Default is 3
nperm
number of permutations. Default is 5000
pwidth
width of the page (in inches). Default is 8.27
pheight
height of the page (in inches). Default is 11.69
margin
margins of the page (in inches). Default is 0.25
filename
file name to save the printout as pdf. If it is saved to pdf, it won't be displayed in the screen. Default is NULL.
colorMapType
what does color map categorizes. It can be pvals, slopes, or years blind. Default is pvals
colorScale
Color mapping to use. Default is NULL. A different default is given depending on colorMapType
ringMapType
what concentric rings categorizes. It can be pvals or slopes, or years blind. Default is NULL, for which no rings are shown.
ringScale
Ring mapping to use. Default is NULL. A different default is given depending on ringMapType
lifeExpectancy
life expectancy in years. Default is 81.27, the CIA estimate for Spain as of 2012 (https://www.cia.gov/library/publications/the-world-factbook/rankorder/2102rank.html)
rangeNormal
range to indicate which slopes are normal. All significance from data points within the range will be removed. Default is NULL.
imparedVision
sensitivity below which it is considered imparement. Default is 10

References

ADD REFERENCES HERE

See Also

vflayout, vflayout_legoplot, poplr, hist_poplr, poplr_cstat, poplr_pstat, vfplot_poplr

Examples

Run this code
vflayout_poplr( vf91016right )

Run the code above in your browser using DataLab