Learn R Programming

visualFields (version 0.2-4)

vfobject: visualField objects

Description

This is the main object of the visualFields package. It is essentially a dataframe, but with a fixed number of columns (with pre-determined names) for information about the subject and test data and a variable number of columns for the perimetry results. These can be the sensitivities, or total-deviation values, or pattern-deviation values obtained from standard automatic perimetry (SAP), frequency-doubling perimetry (FDP), or any other perimetry device. (The number of columns for tested locations is variable as is different for different testing patterns, 24-2, 30-2, 10-2, etc.) Mean deviation, Pattern-standard deviation, vfi, etc are stored too in a visualField-type object

Arguments

Details

The fixed columns of the visualField object with information about subject and test are: ll{ id subject identification number tperimetry test perimetry. The type of perimetry analysys performed. Possible values include "sap" and "fdp". The value of this column, tperimetry, is used in conjunction with the value in talgorithm, and tpattern to find the corresponding normative values (see help on nv) to use for data analysis (e.g. calculation of total-deviation and pattern-deviation values and probability maps). At the moment, only normative values for SAP, 24-2, SITA standard, is distributed with visualFields. Nevertheless, visualFields contains a number of functions that can be used for the generation of normative values (see getnv, ageLinearModel, sdnv, tdval, pdval, locperc, vfstats, vfindex, gloperc, vfiperc, setnv). talgorithm test algorithm. The algorithm used for the perimetric test. Posible values are sitas and zest. At the moment, only normative values for SAP, 24-2, SITA standard, is distributed with visualFields tpattern test pattern. The pattern of locations used for the perimetric test. Posible values are p24d2 or p10d2. At the moment, only normative values for SAP, 24-2, SITA standard, is distributed with visualFields tdate test date ttime test time stype type of subject. Values can be ctr for controls, pwg for patients with glaucoma, sus for suspect subjects. This is just for information to display in the printouts sage subject age. Important for the calculation of total-deviation values and probabiliby maps. seye eye tested sbsx estimated x-position of the blind spot in degrees of angle of vision sbsy estimated y-position of the blind spot in degrees of angle of vision sfp false positives sfn false negatives sfl fixation losses sduration total duration of the test spause total time of pause } The reminder of the columns can be different things. For threshold sensitivity values, and total-deviation and pattern-deviation values, and their corresponding probability maps, they are: ll{ L1 .. L54 .. L68 .. L76 location number. There are up to 54 locations for the 24-2, up to 68 for the 10-2, and 76 for the 30-2. Information about the position of the locations, the size of the stimulus, and the x and y coordinates in degrees of visual angles are specified in saplocmap (for SAP) fdplocmap (for FDP) } For statistical values of the visual-fields results (mean deviation, pattern standard deviation, and others) and their corresponding probability mapped value, they are: ll{ msens mean sensitivity value; or the probability mapped value ssens standard deviation of the sensitivity values; or the probability mapped value mtdev mean deviation (mean value of the total-deviation values; or the probability mapped value) stdev standard deviation of the total-deviation values; or the probability mapped value mpdev mean value of the pattern-deviation values; or the probability mapped value) stdev standard pattern deviation (standard deviation pattern-deviation values; or the probability mapped value } For visual field index (VFI) value and the corresponding probability mapped value, they are: ll{ mvfi visual field indes (VFI); or the probability mapped value svfi standard deviation of the VFI at each location; or the probability mapped value }

See Also

vfsettings

Examples

Run this code
# DO NOT EXECUTE
### ALL THESE HAVE THE SAME STRUCTURE WITH FIXED COLUMS id .. spause and then L1 .. L54 BUT DIFFERENT DATA
# one can load sensitivities using loadvfcsv or loadvfxml the data so
# vf <- loadvfcsv( filename = "foo.csv", , patternMap = saplocmap$p24d2 )
# calculate total deviation values using \code{\link{visualFields}} normative values for SAP SITAS 24-2 (and Goldman size III stimulus)
# td <- tdval( vf )
# calculate pattern deviation values using total deviation values SAP SITAS 24-2 (and Goldman size III stimulus)
# pd <- tdval( td )
# OR
# pd <- tdval( tdval( vf ) )
# calculate total deviation proabiliby maps
# tdp <- tdpmap( td )
# calculate pattern deviation proabiliby maps
# pdp <- pdpmap( pd )

Run the code above in your browser using DataLab