Usage
vfplot( vf, plotType, notSeenAsBlack = TRUE, newWindow = FALSE,
txtfont = "Helvetica", pointsize = 7, width = 6,
xminmax = 29, yminmax = 29,
outerSymbol = "circles", innerSymbol = "circles",
outerSize = 1, innerSize = 1,
outerInch = 0.14, innerInch = 0.08,
lengthLines = 4.25, thicknessLines = 2 )Arguments
vf
vf-object with sensitivity thresholds, or TD or PD valuesplotType
Type of plot to show. It can be visual sensitivities (vf), total-deviation values (td), or pattern-deviation values (pd)
notSeenAsBlack
whether to plot non-seen as black. Default is TRUE
newWindow
whether to generate a new window for the plot. This becomes important when working with RStudio. Default value is TRUE
txtfont
font face of the text with visual-sensitivity values. Default is Helvetica
pointsize
size of the text with visual-sensitivity values. Default is 7
width
width of the window. height is calculated using the width, xminmax, and yminmax. Default is 6
xminmax
minimum and maximum limits on the x axis, in degrees of visual angle. Default is 29
yminmax
minimum and maximum limits on the y axis, in degrees of visual angle. Default is 29
outerSymbol
The outer symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
innerSymbol
The inner symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
outerSize
Relative size of the outer symbol. Default is 1
innerSize
Relative size of the inner symbol. Default is 1
outerInch
Maximum size of the outer symbol in inches. Default is 0.14
innerInch
Maximum size of the inner symbol in inches. Default is 0.08
lengthLines
length of the lines denoting the orientation of the RNFL bundle. Default is 4.25
thicknessLines
thickness of the lines denoting the orientation of the RNFL bundle. Default is 2