Learn R Programming

visualFields (version 0.2-4)

vfplot_poplr: plot with the PoPLR analysis

Description

plots the slope values and the corresponding probabiliby category for each location

Usage

vfplot_poplr( sl, pval, vfinfo, newWindow = FALSE, txtfont = "mono",
              pointsize = 7, width = 6,
              xminmax = 29, yminmax = 29,
              outerSymbol = "circles", innerSymbol = "circles",
              outerSize = 1, innerSize = 1,
              outerInch = 0.24, innerInch = 0.12,
              lengthLines = 3.0, thicknessLines = 2,
              colorMapType = "pval", colorScale = NULL,
              ringMapType  = NULL, ringScale  = NULL,
              lifeExpectancy = 81.27, imparedVision = 10,
              borderThickness = 2,
              idxNotSeen = NULL, rangeNormal = NULL, conormal = NULL )

Arguments

sl
slopes
pval
pvalues calculated for the slope
vfinfo
information about the visual field
newWindow
boolean value- TRUE will generate a new window for the plot. Default value is TRUE
txtfont
font of the text with visual-sensitivity values. Default is mono
pointsize
size of the text with visual-sensitivity values. Default is 7
width
width of the window. height is calucated using the width, xminmax and yminmax
xminmax
minimum and maximum limits on the x axis
yminmax
minimum and maximum limits on the y axis
outerSymbol
The outer symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
innerSymbol
The inner symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
outerSize
Relative size of the outer symbol. Default is 1
innerSize
Relative size of the inner symbol. Default is 1
outerInch
Maximum size of the outer symbol in inches. Default is 0.2
innerInch
Maximum size of the inner symbol in inches. Default is 0.1
lengthLines
length of the lines denoting the orientation of the RNF bundle
thicknessLines
thickness of the lines denoting the orientation of the RNF bundle
colorMapType
what does color map categorizes. It can be pvals, slopes, or years blind. Default is pvals
colorScale
Color mapping to use. Default is NULL. A different default is given depending on colorMapType
ringMapType
what concentric rings categorizes. It can be pvals or slopes, or years blind. Default is NULL, for which no rings are shown.
ringScale
Ring mapping to use. Default is NULL. A different default is given depending on ringMapType
lifeExpectancy
life expectancy in years. Default is 81.27, the CIA estimate for Spain as of 2012 (https://www.cia.gov/library/publications/the-world-factbook/rankorder/2102rank.html)
imparedVision
sensitivity below which it is considered imparement. Default is 10
borderThickness
Thickness of the borders if ringMapType is not NULL. Default is 5
idxNotSeen
index of locations that are not seen. These locations will be displayed with a solid balck circle. Default is NULL.
rangeNormal
range to indicate which slopes are normal. All significance from data points within the range will be removed. Default is NULL.
conormal
if a rangeNormal is defined, then this specifies the within-normal category. Default is NULL. If colorMapType = "pval", then it is 95, if colorMapType = "slope", then it is 0.5

Details

The vfplot function operates on a single row of visual fileds (vf). Depending on the plot type it will generate a plot representing the sensitivity at each location. The color scheme elucidates the degree of sensitivity at that location. Locations with zero sensitivity are shown in black. Blind spots have been excluded fronm the plot

References

ADD REFERENCES HERE

See Also

poplr, hist_poplr, poplr_cstat, poplr_pstat, vflayout_poplr

Examples

Run this code
res <- poplr( vf91016right )
vfplot_poplr( res$sl, res$pval, res$vfdata, newWindow = TRUE )

Run the code above in your browser using DataLab