Learn R Programming

visualFields (version 0.2-4)

vfplotloc: visual field data plot

Description

plots location-specific data at each location of the visual field. It is the function called by vfplot

Usage

vfplotloc( vals, eye, patternMap, outerColor, innerColor = NULL, bs = NULL,
           axesCol = "black", txtfont = "mono", pointsize = 7,
           txtcolor = NULL, xminmax = 29, yminmax = 29, outerSymbol = "circles",
           innerSymbol = "circles", outerSize = 1, innerSize = 1,
           outerInch = 0.2, innerInch = 0.1, lengthLines = 2.5,
           thicknessLines = 2, outerBorderColor = NULL, innerBorderColor = NULL,
           outerBorderThickness = 2, innerBorderThickness = 2 )

Arguments

vals
sensitivity threshold, TD or PD values, or other location-specific values
eye
eye being tested
patternMap
locations where to plot symbols, the TD and PD values
outerColor
colors to use for the outer symbols in the graph
innerColor
colors to use for the outer symbols in the graph. Default is NULL, meaning white
bs
location of the blind spot. Default is NULL meaning do not show blind spot
axesCol
color of the axes. Default is black
txtfont
font of the text with visual-sensitivity values. Default is mono
pointsize
size of the text with visual-sensitivity values. Default is 7
txtcolor
color of text. Default is black
xminmax
minimum and maximum limits on the x axis
yminmax
minimum and maximum limits on the y axis
outerSymbol
The outer symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
innerSymbol
The inner symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
outerSize
Relative size of the outer symbol. Default is 1
innerSize
Relative size of the inner symbol. Default is 1
outerInch
Maximum size of the outer symbol in inches. Default is 0.2
innerInch
Maximum size of the inner symbol in inches. Default is 0.1
lengthLines
length of the lines denoting the orientation of the RNF bundle
thicknessLines
thickness of the lines denoting the orientation of the RNF bundle
outerBorderColor
Border for outer symbol denoting statistical significance. Default is NULL
innerBorderColor
Color of the inner border that represents statistical significance. Default is NULL.
outerBorderThickness
Thickness of outer border for outer symbol denoting statistical significance. Default is 2
innerBorderThickness
Thickness of the inner border that represents statistical significance. Default is 2

Details

The vfplot function operates on a single row of visual fileds (vf). Depending on the plot type it will generate a plot representing the sensitivity at each location. The color scheme elucidates the degree of sensitivity at that location. Locations with zero sensitivity are shown in black. Blind spots have been excluded fronm the plot

See Also

vfplot

Examples

Run this code
# DO NOT EXECUTE
#vfplotloc( vals )

Run the code above in your browser using DataLab