powered by
extracts a block from the XML file
xmlblock( tag, xmllines, capitalize = TRUE )
tag to look at
lines from loaded XML files
Whether we need to capitalize or not. Default is TRUE
TRUE
returns an array of characters with all that is inside a block corresponding to a particular tag
loadvfxml, loadvfcsv, xmlitem
loadvfxml
loadvfcsv
xmlitem
# NOT RUN { # DO NOT RUN #xmlblock( tag, xmllines ) # }
Run the code above in your browser using DataLab