Learn R Programming

visualFields (version 0.2-4)

xmlvfxy: dxtraction of (x,y)-coordinates of tested locations

Description

extracts the (x,y)-coordinates of tested locations

Usage

xmlvfxy( xmllines )

Arguments

xmllines
lines from loaded XML files

Value

  • (x,y)-coordinates of tested locations

Details

extracts the (x,y)-coordinates of tested locations. To be used only for custom locations, not when we know that the testing pattern is 24-2, or 30-2, etc

See Also

loadvfxml, xmlvfval

Examples

Run this code
# DO NOT RUN
#xmldevval( xmllines )

Run the code above in your browser using DataLab