Usage
colormapgraph( ncol = 3, mapval = nv$pmapsettings, notSeenAsBlack = TRUE,
txtfont = "mono", pointsize = 7,
outerSymbol = "circles", innerSymbol = "circles",
outerSize = 1, innerSize = 1,
outerInch = 0.2, innerInch = 0.1 )Arguments
ncol
number of columns in where to show the color symbols. Default is 3
notSeenAsBlack
Add a black color-code representing non-seen to the color scheme of the probability maps for td and pd
mapval
map and cutoff values to be used for the generation of the color map. Default is nv$pmapsettings
txtfont
font of the text with visual-sensitivity values. Default is mono
pointsize
size of the text with visual-sensitivity values. Default is 7
outerSymbol
The outer symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
innerSymbol
The inner symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
outerSize
Size of the outer symbol. Default is 1
innerSize
Size of the inner symbol. Default is 1
outerInch
Maximum size of the outer symbol in inches. Default is 0.2
innerInch
Maximum size of the inner symbol in inches. Default is 0.1