It geneartes color legend for p-values in td and pd probability plots
colormapgraph( ncol = 3,
mapval = visualFields::vfenv$nv$pmapsettings,
notSeenAsBlack = TRUE,
txtfont = "mono", pointsize = 7,
outerSymbol = "circles", innerSymbol = "circles",
outerSize = 1, innerSize = 1,
outerInch = 0.2, innerInch = 0.1 )number of columns in where to show the color symbols. Default is 3
Add a black color-code representing non-seen to the color scheme of the probability maps for td and pd
map and cutoff values to be used for the generation of the color map. Default is nv$pmapsettings
font of the text with visual-sensitivity values. Default is mono
size of the text with visual-sensitivity values. Default is 7
The outer symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
The inner symbol at all locations. Can be any of circles, squares, rectangles, stars. Default is circle
Size of the outer symbol. Default is 1
Size of the inner symbol. Default is 1
Maximum size of the outer symbol in inches. Default is 0.2
Maximum size of the inner symbol in inches. Default is 0.1
it generates a graph with the color legend for p-values in td and pd probability plots given the actual normative values version set for visualFields
# NOT RUN {
colormapgraph()
# }
Run the code above in your browser using DataLab