pattern of stimulus locations. Default is saplocmap$p24d2
typeData
Type of data to load; visual field (vf), total deviations (td), pattern deviations (pd), global indices (gi), visual-field index (vfi), total-deviation p-values (tdp), pattern-deviation p-values (pdp), global indices probability maps (gip), visual-field-index probability map (vfip). Default is vf
typeSubject
Type of subject, control (ctr) or patient (pwg). Default is (pwg)
extractionType
When typeData is (vf) what type of extraction we want: all re-tested sensitivities "all" or just the mean "average" over re-tested values? Default is "average"
daysyear
if NULL, calculates real age. If informed, then calculates year based on the number of days per year (e.g. 362.25)
Value
returns a vf-object with one row containing the information for the subject loaded in the XML
Details
The XML files format must be as from the extraction of the HFA device