powered by
creates a printout with results for the visual field. This includes sensitivity threshold values with a gray scale plot, and TD and PD values with color coding for the probability map
vflayout( vf, pwidth = 8.27, pheight = 11.69, margin = 0.25, filename = NULL, showaxis = FALSE, colaxis = "black" )
vf-object with sensitivity thresholds
vf
width of the page (in inches). Default is 8.27
8.27
height of the page (in inches). Default is 11.69
11.69
margins of the page (in inches). Default is 0.25
0.25
file name to save the printout as pdf. If it is saved to pdf, it won't be displayed in the screen. Default is NULL.
NULL
Whether to show axis or not. Default is FALSE
FALSE
Color of the axis to show, if showaxis is TRUE. Default is black
showaxis
TRUE
black
vflayoutghr, vfplot, vfplotloc
vflayoutghr
vfplot
vfplotloc
# NOT RUN { # } # NOT RUN { vflayout( vf91016right[15,] ) # }
Run the code above in your browser using DataLab