vfsegmentcoord: calculate line segments to plot in vfplot representing the overall orientation of the retinal nerve fibre layer bundles according to Jansonious map [1]
Description
This function geneartes coordinates for the line segments to be plotted
Usage
vfsegmentcoord( lineMap, length = 3.75 )
Arguments
lineMap
patternMap having x,y and slope values
length
length of the line segment in inches. Default is 3.75
Details
This function geneartes coordinates for the line segments to be plotted. Based on the location (x,y) and slope, this function claculates the coordinate set {(x1,y1),(x2,y2)} which is used to plot the line segments
References
[1] N. M. Jansonius, J. Nevalainen, B. Selig, L. M. Zangwill, P. A. Sample, W. M. Budde, J. B. Jonas, W. A. Lagreze, P. J. Airaksinen, R. Vonthein, L. A. Levin, J. Paetzold, and U. Schiefer. A mathematical description of nerve fiber bundle trajectories and their variability in the human retina. Vision Research, 49, 2009.