visualFields-package: Statistical methods for visual fields
Description
This is a collection of tools for analyzing the field of vision. It provides a framework for the development and use of innovative methods for visualization, statistical analysis, and clinical interpretation of visual-field loss and its change over time. visualFields is intended to be a tool for collaborative researchDetails
This work was supported by NIH grant number R01EY007716. We thank the following people who contributed to the package
ll{
Chaitanya Khadilkar developer
Neil O'Leary provided the original implementation of PoPLR in MatLab
William H Swanson provided data for control subjects for the generation of normative values
Victor E Malinovsky provided data for control subjects for the generation of normative values
Mitchell W Dul provided data for control subjects for the generation of normative values
Richard Russell provided some code to read XML files extracted from the HFA
}References
ADD REFERENCES HERE